HostAddrResolver

Struct HostAddrResolver 

pub struct HostAddrResolver<R> { /* private fields */ }
A resolver which supports both domain:port and socket address. However, it will only use ToSocketAddrs to resolve the address.

N.B. If a domain contains multiple ip addresses, there is no guarantee that which one will be used. Users should make sure that the domain only contains one ip address, to make sure that AddressResolver can work properly.

e.g. valid address format:

  1. www.example.com:8080 // domain
  2. [::1]:8080 // ipv6
  3. 127.0.0.1:8080 // ipv4

Implementations

Source

impl<R> HostAddrResolver<R>

pub fn new(opts: HostAddrResolverOptions) -> HostAddrResolver<R>

Create a new HostAddrResolver with the given options.