pub struct HostAddrResolver<R> { /* private fields */ }Expand description
A resolver which supports both domain:port and socket address. However,
it will only use ToSocketAddrs
to resolve the address.
- If you can make sure, you always play with
SocketAddr, you may want to useSocketAddrResolver. - If you want to send DNS queries, you may want to use
DnsResolver.
N.B. If a domain contains multiple ip addresses, there is no guarantee that
which one will be used. Users should make sure that the domain only contains
one ip address, to make sure that AddressResolver can work properly.
e.g. valid address format:
www.example.com:8080// domain[::1]:8080// ipv6127.0.0.1:8080// ipv4
Implementations
Sourceimpl<R> HostAddrResolver<R>
impl<R> HostAddrResolver<R>
Sourcepub fn new(opts: HostAddrResolverOptions) -> HostAddrResolver<R>
pub fn new(opts: HostAddrResolverOptions) -> HostAddrResolver<R>
Create a new HostAddrResolver with the given options.